Function nvim_gtk::file_browser::reveal_path_in_tree
source · [−]Expand description
Reveals and selects the given file in the file browser.
Returns true if the file could be successfully revealed.
Reveals and selects the given file in the file browser.
Returns true if the file could be successfully revealed.