pub enum NeovimRef<'a> {
    SingleThreaded(RefMut<'a, Neovim>),
    MultiThreaded(MutexGuard<'a, Option<Neovim>>),
}

Variants

SingleThreaded(RefMut<'a, Neovim>)

MultiThreaded(MutexGuard<'a, Option<Neovim>>)

Implementations

Methods from Deref<Target = Neovim>

Register as a remote UI.

After this method is called, the client will receive redraw notifications.

Send a quit command to Nvim. The quit command is ‘qa!’ which will make Nvim quit without saving anything.

Same as ui_set_option but use UiOption as argument to check type at compile time