pub struct SubscriptionHandle {
    key: SubscriptionKey,
    index: usize,
}
A handle to identify a Subscription within the Subscriptions map.

Can be used to trigger the subscription manually even when the event was not triggered.

Could be used in the future to suspend individual subscriptions.

Fields

key: SubscriptionKeyindex: usize