pub trait ModelClipIteratorFactory {
fn get_clip_iterator<'a>(
&'a self,
ctx: &'a Context,
cell_metrics: &'a CellMetrics
) -> ModelClipIterator<'_>ⓘNotable traits for ModelClipIterator<'a>impl<'a> Iterator for ModelClipIterator<'a> type Item = RowView<'a>;;
fn get_row_view<'a>(
&'a self,
ctx: &'a Context,
cell_metrics: &'a CellMetrics,
col: usize
) -> RowView<'a>;
}Required Methods
sourcefn get_clip_iterator<'a>(
fn get_clip_iterator<'a>(
&'a self,
ctx: &'a Context,
cell_metrics: &'a CellMetrics
) -> ModelClipIterator<'_>ⓘNotable traits for ModelClipIterator<'a>impl<'a> Iterator for ModelClipIterator<'a> type Item = RowView<'a>;
sourcefn get_row_view<'a>(
fn get_row_view<'a>(
&'a self,
ctx: &'a Context,
cell_metrics: &'a CellMetrics,
col: usize
) -> RowView<'a>
Implementors
impl ModelClipIteratorFactory for UiModel
Clip implemented as top - 1/bot + 1 this is because in some cases(like ‘g’ character) drawing character does not fit to calculated bounds and if one line must be repainted - also previous and next line must be repainted to