Struct nvim_gtk::subscriptions::Subscription
source · [−]Expand description
A subscription to a Neovim autocmd event.
Fields
cb: Box<dyn Fn(Vec<String>) + 'static>A callback to be executed each time the event triggers.
args: Vec<String>A list of expressions which will be evaluated when the event triggers. The result is passed to the callback.